==> chzzkpy-1.0.0.tar.gz: chzzkpy-1.0.0/chzzkpy/chat/__init__.py <==
"""MIT License

Copyright (c) 2024 gunyu1019

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from .blind import Blind
from .chat_client import ChatClient
from .connected import ConnectedInfo
from .enums import ChatType, ChatCmd, UserRole
from .error import *
from .message import (
    ChatMessage,
    NoticeMessage,
    DonationMessage,
    SubscriptionMessage,
    SystemMessage,
    Extra,
    NoticeExtra,
    SystemExtra,
    ChatDonationExtra,
    VideoDonationExtra,
    MissionDonationExtra,
)
from .profile import Profile, ActivityBadge, StreamingProperty, Badge
from .recent_chat import RecentChat

==> chzzkpy-1.1.0.tar.gz: chzzkpy-1.1.0/chzzkpy/chat/__init__.py <==
"""MIT License

Copyright (c) 2024 gunyu1019

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from .blind import Blind
from .chat_client import ChatClient
from .connected import ConnectedInfo
from .donation import (
    DonationRank,
    BaseDonation,
    ChatDonation,
    VideoDonation,
    MissionDonation,
)
from .enums import ChatType, ChatCmd
from .error import *
from .message import (
    Message,
    MessageDetail,
    ChatMessage,
    NoticeMessage,
    DonationMessage,
    SubscriptionMessage,
    SystemMessage,
    Extra,
    ChatDonationExtra,
    VideoDonationExtra,
    MissionDonationExtra,
    SubscriptionExtra,
    NoticeExtra,
    SystemExtra,
    SystemExtraParameter,
)
from .profile import Profile, ActivityBadge, StreamingProperty, Badge
from .recent_chat import RecentChat
